'--------------------------------------------------------------------------------
' Copyright (c) 2001-2008 by PDFTron Systems Inc. All Rights Reserved.
'--------------------------------------------------------------------------------

Imports System
Imports System.Runtime.InteropServices

Module Module1

    Public Delegate Function PDF2SVGCallback(ByVal mode As Integer, ByVal msg As String, ByVal user_data As IntPtr) As Int32

	' The following lines import the PDF2SVG functions from PDF2SVG.dll (via PInvoke).
    <DllImport("pdf2svg.dll", ExactSpelling:=False)> _
    Public Function PDF2SVGInit _
     (ByVal user_name As String, ByVal company As String, ByVal license_key As String, ByVal resource_path As String) As Int32
    End Function

    <DllImport("pdf2svg.dll", ExactSpelling:=False)> _
    Public Function PDF2SVGRun _
     (ByVal command_str As String, ByVal funct As PDF2SVGCallback, ByVal user_data As IntPtr) As Int32
    End Function


    ' You can modify the following lines with your registration information.
    Dim username As String = "John Doe"
    Dim company As String = "My Company"
    Dim lic_key As String = "my license key"

    Dim PDF2SVG_ERROR As Integer = 1    ' Show the error message
    Dim PDF2SVG_MSG As Integer = 2  ' Report the message
    Dim PDF2SVG_GETPASS As Integer = 3    ' Get the password
    Dim PDF2SVG_OUT_FILENAME As Integer = 4 ' Get the saved filenames

    ' A custom callback that can be used to report errors and other messages.
    Public Function MyCallback(ByVal mode As Integer, ByVal msg As String, ByVal user_data As IntPtr) As Int32
        If mode = PDF2SVG_ERROR Then
            Console.WriteLine("Error: {0}", msg)
        ElseIf mode = PDF2SVG_MSG Then
            Console.Write("{0}", msg)
        ElseIf mode = PDF2SVG_OUT_FILENAME Then
            If user_data.ToInt32 <> 0 Then
                'add the next saved filename to the given ArrayList
                Dim gch As GCHandle = GCHandle.op_Explicit(user_data)
                Dim list As ArrayList = CType(gch.Target, ArrayList)
                list.Add(msg)
            End If
        End If

        Return 0
    End Function 'MyCallback


    Sub Main(ByVal args() As String)
        Dim mycbk As PDF2SVGCallback
        mycbk = AddressOf MyCallback

        PDF2SVGInit(username, company, lic_key, Nothing)

        ' Variable used to switch between different code samples.
        Dim example As Integer = 1

        If example = 1 Then

            ' The simplest PDF2SVG program: Pass an explicit command-line string.
            '
            ' This example converts 'tiger.pdf' to 'tiger.svg'
            ' To convert all PDF documents in 'TestFiles' folder simply delete 'tiger.pdf'
            ' from the command string.
            ' 
            ' For a detailed explanation of all commands, please refer to PDF2SVG SDK User 
            ' Manual. Also, PDF2SVG Command-Line application is a great tool to experiment 
            ' with the available options.
            Dim str As String = "-o TestOutput/test1 TestFiles/tiger.pdf"
            PDF2SVGRun(str, mycbk, New IntPtr(0))

        ElseIf example = 2 Then
            ' An example of how to use PDF2SVG SDK to implement a command-line application
            ' for converting PDF documents to SVG.
            Dim s As String = ""
            Dim arg As String
            For Each arg In args
                s += arg
                s += " "
            Next
            PDF2SVGRun(s, mycbk, New IntPtr(0))

        ElseIf example = 3 Then

            ' An example of how to dynamically build a command string based on 
            ' user settings...
            '
            ' Please note that this sample does not cover all possible options offered by 
            ' PDF2SVG. For a detailed explanation of all commands, please refer to PDF2SVG 
            ' SDK User Manual.
            Dim output_folder As String = "TestOutput/test1"
            Dim open_password As String = "secret"
            Dim compress_using_svgz As Boolean = True
            Dim embedimages As Boolean = True
            Dim generate_xml_masterdoc As Boolean = False
            Dim generate_thumbnails As Boolean = False
            Dim thumbsize As Integer = 150
            Dim filename_prefix As String = ""
            Dim filename_digits As Integer = 4

            ' Given the above settings build a command string.
            Dim s As String = ""

            If Not output_folder = "" Then
                s += "-o " + output_folder + " "
            End If
            If Not open_password = "" Then
                s += "-p " + open_password + " "
            End If

            If compress_using_svgz Then
                s += "--svgz "
            End If

            If embedimages Then
                s += "--embedimages "
            End If

            If Not generate_xml_masterdoc Then
                s += "--noxmldoc "
            End If

            If generate_thumbnails Then
                s += "--thumbsize " + thumbsize.ToString + " "
            Else
                s += "--nothumbs "
            End If

            If Not filename_prefix = "" Then
                s += "--prefix " + filename_prefix + " "
            End If

            If filename_digits > 0 Then
                s += "--digits " + filename_digits.ToString + " "
            End If

            ' specify input PDF files and folders...
            s += "TestFiles/tiger.pdf "
            s += "TestFiles/tai962.pdf "
            ' s += "c:/my_pdf_folder "; etc ...

            ' Execute the command string.
            'An ArrayList to store the paths of saved files
            Dim saved_files As New ArrayList

            'Get a handle for the ArrayList so that it
            'can be used in the MyCallback function
            Dim gch As GCHandle = GCHandle.Alloc(saved_files)
            ' Execute the command string.
            PDF2SVGRun(s, mycbk, GCHandle.op_Explicit(gch))
            gch.Free()

            'print the saved file(s)
            Console.WriteLine("The Saved Files Are:")
            For i As Integer = 0 To saved_files.Count - 1
                Console.WriteLine(saved_files(i))
            Next

        End If

        Console.WriteLine("Done.")
    End Sub
End Module
